import{f as l,e7 as o,f0 as d}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1e7c23d0-c2cd-4806-a426-5b22505179dc",e._sentryDebugIdIdentifier="sentry-dbid-1e7c23d0-c2cd-4806-a426-5b22505179dc")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(c){return Object.getOwnPropertyDescriptor(n,c).enumerable}))),r.forEach(function(c){u(e,c,n[c])})}return e}function u(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=a({},t,n.attrs);return l(o,a({},r,{icon:d}),null)};i.displayName="ExclamationCircleOutlined";i.inheritAttrs=!1;const s=i;export{s as E};
//# sourceMappingURL=ExclamationCircleOutlined.6c9b6350.js.map
