import{X as s,dL as i,dM as d}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="a1eb24a8-f31b-4905-a128-cc64235bf0d8",e._sentryDebugIdIdentifier="sentry-dbid-a1eb24a8-f31b-4905-a128-cc64235bf0d8")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:b,QuarterPicker:a,RangePicker:o}=i(d),u=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:b,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.2b495b83.js.map
