import{d as o,o as s,a5 as a,f as d,u as _,S as r,_ as c}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="56e67153-589d-40fc-8415-ef72b259e515",e._sentryDebugIdIdentifier="sentry-dbid-56e67153-589d-40fc-8415-ef72b259e515")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(s(),a("div",i,[d(_(r))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.cd304a5d.js.map
