import{P as m}from"./PlayerNavbar.16f29265.js";import{d as g,e5 as h,ea as i,r as y,c as k,m as v,a5 as b,u as a,a as w,h as L,e as C,f as I,o as c,_ as N}from"./jwt-decode.esm.c1356de1.js";import{u as V}from"./workspaceStore.99340033.js";import"./userStore.247d5358.js";import"./metadata.6da4e24c.js";import"./PhWebhooksLogo.vue.fe9be825.js";import"./LoadingOutlined.257389ed.js";import"./PhSignOut.vue.ce223c0a.js";import"./index.82da6b22.js";import"./runnerData.f4160ef6.js";import"./url.99373f08.js";import"./colorHelpers.49707a83.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="484f1f42-0a9f-4660-889b-5d1f9882f053",o._sentryDebugIdIdentifier="sentry-dbid-484f1f42-0a9f-4660-889b-5d1f9882f053")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=i().path,n=y(null),d=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},f=k(()=>!!i().meta.hideLogin);return(r,s)=>{const _=v("RouterView");return c(),b("div",x,[a(t).state.workspace?(c(),w(m,{key:0,"current-path":a(u),"hide-login":f.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(_)])])}}});const G=N(D,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main.809c7be4.js.map
