import{P as a}from"./record.6e317d8b.js";import{q as d,r}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2f36cc39-1262-401e-a4e6-4afb06d5dd24",e._sentryDebugIdIdentifier="sentry-dbid-2f36cc39-1262-401e-a4e6-4afb06d5dd24")}catch{}})();const i=new a,b=d("omniChat",()=>{const e=r(!0),t=r(!1),n=()=>{t.value=!0},o=()=>{t.value=!1},s=()=>{e.value=!0,n()},u=()=>{e.value=!1,o()};return{isOpen:e,isInputFocused:t,focusInput:n,blurInput:o,open:s,close:u,toggle:()=>{e.value?u():s()}}});export{i as o,b as u};
//# sourceMappingURL=omniChatStore.6b2bc826.js.map
