import{O as r}from"./userStore.247d5358.js";import{d as l,k as i,a5 as u,f as a,b as d,u as n,o as c,g as o,A as f,d8 as _}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="afd7edd7-3e8a-4297-b773-dd63c9091e80",e._sentryDebugIdIdentifier="sentry-dbid-afd7edd7-3e8a-4297-b773-dd63c9091e80")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(n(f),null,{default:d(()=>[o("You're authenticated")]),_:1}),a(n(_),null,{default:d(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.f4ead864.js.map
