import{_}from"./Login.vue_vue_type_script_setup_true_lang.8e4e9b09.js";import{d as l,e5 as m,ea as b,a5 as g,f as y,u as n,o as w,_ as k}from"./jwt-decode.esm.c1356de1.js";import{u as h}from"./workspaceStore.99340033.js";import"./userStore.247d5358.js";import"./CircularLoading.f125bcad.js";import"./Logo.df26cd08.js";import"./string.dbe1a2f4.js";import"./index.04b3ace7.js";import"./runnerData.f4160ef6.js";import"./url.99373f08.js";import"./colorHelpers.49707a83.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="01fffb34-3414-472c-b379-ffbb2e129fcf",e._sentryDebugIdIdentifier="sentry-dbid-01fffb34-3414-472c-b379-ffbb2e129fcf")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),t=b(),r=h(),d=async()=>{const{redirect:s,...a}=t.query;if(s){await o.push({path:s,query:a,params:t.params});return}o.push({name:"playerHome",query:a})};return(s,a)=>{var c,f,p,u,i;return w(),g("div",v,[y(_,{"logo-url":(f=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?f:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:d},null,8,["logo-url","brand-name","locale"])])}}});const U=k(I,[["__scopeId","data-v-cb33c596"]]);export{U as default};
//# sourceMappingURL=Login.90e65c42.js.map
