import{A as o}from"./index.c27622fb.js";import{d as a,c as r,a5 as p,f as d,u as f,e9 as c,h as l,o as i,_ as u}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="9d56e1e2-6ce9-4a89-ab4e-f3d48db5cf4b",e._sentryDebugIdIdentifier="sentry-dbid-9d56e1e2-6ce9-4a89-ab4e-f3d48db5cf4b")}catch{}})();const _=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,b)=>t.stepsInfo?(i(),p("nav",{key:0,class:c(["p-steps",{"full-screen":!t.isPreview}])},[d(f(o),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):l("",!0)}});const I=u(_,[["__scopeId","data-v-8b0ea4f1"]]);export{I as S};
//# sourceMappingURL=Steps.2a493034.js.map
