import{S as c,O as i,d,a as l}from"./log.0bd79fdf.js";import{d as p,ea as u,o as f,a as m,u as n}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0709ed95-5594-43c6-9130-3cb711a8872d",e._sentryDebugIdIdentifier="sentry-dbid-0709ed95-5594-43c6-9130-3cb711a8872d")}catch{}})();const h=p({__name:"ConsoleOmniChat",setup(e){const o=u().params.projectId,r=new d(o),s=l.create(),a=new c(r,s,null,{origin:"console",projectId:o});return(y,_)=>(f(),m(i,{"ai-chat-repository":n(r),controller:n(a),environment:{origin:"console",projectId:n(o)}},null,8,["ai-chat-repository","controller","environment"]))}});export{h as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.7ad7494f.js.map
