import{C as n}from"./controller.6ad7dde1.js";import{d as p,ea as i,a as s,u as a,o as m}from"./jwt-decode.esm.c1356de1.js";import{_ as f}from"./View.vue_vue_type_script_setup_true_lang.4b0e3383.js";import"./router.10a36819.js";import"./index.70806805.js";import"./fetch.0b2e8c07.js";import"./record.6e317d8b.js";import"./PhPencil.vue.bc89e8c2.js";import"./SaveButton.9c6a5df2.js";import"./ExclamationCircleOutlined.6c9b6350.js";import"./CrudView.75d6f80a.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.e8f82a36.js";import"./constants.31a5b2c9.js";import"./url.99373f08.js";import"./PhDotsThreeVertical.vue.a655f2e4.js";import"./index.33815650.js";import"./asyncComputed.c4333d47.js";import"./polling.b00cc5ce.js";import"./omniChatStore.6b2bc826.js";import"./index.04b3ace7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="98a836a8-efc3-4bdf-92da-1f35df3fe4b5",o._sentryDebugIdIdentifier="sentry-dbid-98a836a8-efc3-4bdf-92da-1f35df3fe4b5")}catch{}})();const q=p({__name:"EnvVars",setup(o){const e=i().params.projectId,t=new n(e);return(d,c)=>(m(),s(f,{"env-var-repository":a(t),mode:"console"},null,8,["env-var-repository"]))}});export{q as default};
//# sourceMappingURL=EnvVars.bfc092bc.js.map
