import{d as o,a5 as a,e as s,a7 as l,e9 as n,o as r,_ as f}from"./jwt-decode.esm.c1356de1.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b2c4f50d-6f6d-42c6-967c-3d2686b8ed19",t._sentryDebugIdIdentifier="sentry-dbid-b2c4f50d-6f6d-42c6-967c-3d2686b8ed19")}catch{}})();const c=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(t){return(e,d)=>(r(),a("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[s("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[l(e.$slots,"default",{},void 0,!0)],2)],2))}});const u=f(c,[["__scopeId","data-v-fb4d67f9"]]);export{u as C};
//# sourceMappingURL=ContentLayout.b79bd195.js.map
