import"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d0865e17-f87d-49ae-80b0-97163fb3054a",e._sentryDebugIdIdentifier="sentry-dbid-d0865e17-f87d-49ae-80b0-97163fb3054a")}catch{}})();const s={HOMEPAGE:"https://abstra.io",DOCS:"https://abstra.io/docs",CLOUD:"https://cloud.abstra.io"},r=e=>{if(!e)return s.DOCS;const t=e.startsWith("/")?e.slice(1):e;return`${s.DOCS}/${t}`};export{s as A,r as b};
//# sourceMappingURL=constants.31a5b2c9.js.map
