import{O as r}from"./userStore.247d5358.js";import{d as l,k as u,a5 as i,f as a,b as n,u as o,o as c,g as s,A as f,d8 as b}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b178127c-3b36-4d5f-9ff8-3e4c90953387",e._sentryDebugIdIdentifier="sentry-dbid-b178127c-3b36-4d5f-9ff8-3e4c90953387")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new r().logoutCallback()}),(t,d)=>(c(),i("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.5c5ad954.js.map
