import{j as a}from"./router.10a36819.js";import"./jwt-decode.esm.c1356de1.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="2df7f37a-4bd9-48a7-9482-7a7f87455ee2",r._sentryDebugIdIdentifier="sentry-dbid-2df7f37a-4bd9-48a7-9482-7a7f87455ee2")}catch{}})();class s{async list(e){return a.get(`organizations/${e}/folders`)}async create(e){return a.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return a.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return a.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{s as F};
//# sourceMappingURL=folder.c054402a.js.map
