import{f as l,e7 as c,e$ as o}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bd04ff3d-dd0a-44c8-96c2-fb05cd74e50f",e._sentryDebugIdIdentifier="sentry-dbid-bd04ff3d-dd0a-44c8-96c2-fb05cd74e50f")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(d){return Object.getOwnPropertyDescriptor(r,d).enumerable}))),n.forEach(function(d){u(e,d,r[d])})}return e}function u(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var f=function(t,r){var n=i({},t,r.attrs);return l(c,i({},n,{icon:o}),null)};f.displayName="CloseCircleOutlined";f.inheritAttrs=!1;const s=f;export{s as C};
//# sourceMappingURL=CloseCircleOutlined.16f446bf.js.map
