import{u as r}from"./userStore.247d5358.js";import{W as n}from"./PlayerConfigProvider.b6bb3f6e.js";import{u as c}from"./workspaceStore.99340033.js";import{d,w as i,m as p,u as o,a as u,b as f,h as l,o as m,f as _}from"./jwt-decode.esm.c1356de1.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="60b4addd-c13d-46ac-b796-9bd44d9271c2",t._sentryDebugIdIdentifier="sentry-dbid-60b4addd-c13d-46ac-b796-9bd44d9271c2")}catch{}})();const v=d({__name:"App",setup(t){const a=r(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(w,b)=>{const s=p("RouterView");return o(e).state.workspace?(m(),u(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:f(()=>[_(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):l("",!0)}}});export{v as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.4f01c0b1.js.map
