import{L as t}from"./Logo.df26cd08.js";import{d as n,o as r,a as d,u as i}from"./jwt-decode.esm.c1356de1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cae12a7e-5e86-4c72-a6c8-36cd379c8fb3",e._sentryDebugIdIdentifier="sentry-dbid-cae12a7e-5e86-4c72-a6c8-36cd379c8fb3")}catch{}})();const c="/assets/logo.0faadfa2.svg",u=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(a,o)=>{var s;return r(),d(t,{"image-url":i(c),"brand-name":"Abstra","hide-text":a.hideText,size:(s=a.size)!=null?s:"small"},null,8,["image-url","hide-text","size"])}}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.7c8fb8cf.js.map
