import{y as n,z as r,B as a,C as o,P as c,D as d,E as p,F as f,G as s,H as m,I as u,J as g,K as y}from"./jwt-decode.esm.c1356de1.js";import{s as l}from"./userStore.247d5358.js";import{_ as w}from"./App.vue_vue_type_style_index_0_lang.4f01c0b1.js";import{a as i}from"./workspaceStore.99340033.js";import"./PlayerConfigProvider.b6bb3f6e.js";import"./colorHelpers.49707a83.js";import"./runnerData.f4160ef6.js";import"./url.99373f08.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ff3d9791-f192-4f69-94c1-5c3c702c4306",t._sentryDebugIdIdentifier="sentry-dbid-ff3d9791-f192-4f69-94c1-5c3c702c4306")}catch{}})();class I{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await l();const t=n(),e=r({render:()=>m(w)});a.init(),o(e,i),I.init(),e.use(i),e.use(t),e.use(c),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",f),s(e,u),s(e,g),s(e,y)})();
//# sourceMappingURL=player.b386d6bc.js.map
